@@ -94,7 +94,6 @@ try:
             return os.getgrouplist(username, user_gid)
 
         def configure(self, config: Config):
-
             config_options = self._make_config()
             config.register(config_options)
 
@@ -113,7 +112,6 @@ try:
             super().configure(config)
 
         async def user_role(self, request: Request, profile: UserProfile):
-
             mappings = [
                 (ServerRole.OWNER, self.admin_groups),
                 (ServerRole.MAINTAINER, self.maintainer_groups),
@@ -128,8 +126,8 @@ try:
                 common = set(role_gids) & set(user_gids)
                 if common:
                     logger.info(
-                        "pam authenticator: user {username} found in group {common}"
-                        "setting {role} permissions"
+                        f"pam authenticator: user {username} found in group {common}, "
+                        f"setting {role} permissions"
                     )
                     return role.value
 
@@ -147,6 +145,10 @@ try:
             if data is None:
                 return None
 
+            host = None
+            if request.client:
+                host = request.client.host
+
             username = data['username']
             try:
                 pamela.authenticate(
@@ -156,12 +158,7 @@ try:
                     encoding=self.encoding,
                 )
             except pamela.PAMError as e:
-                logger.warning(
-                    "PAM Authentication failed (%s@%s): %s",
-                    username,
-                    request.client.host,
-                    e,
-                )
+                logger.warning(f"PAM Authentication failed ({username}@{host}): {e}")
                 return None
 
             if self.check_account:
@@ -170,12 +167,7 @@ try:
                         username, service=self.service, encoding=self.encoding
                     )
                 except pamela.PAMError as e:
-                    logger.warning(
-                        "PAM Account Check failed (%s@%s): %s",
-                        username,
-                        request.client.host,
-                        e,
-                    )
+                    logger.warning(f"PAM Account Check failed ({username}@{host}): {e}")
                     return None
 
             return username
