@@ -67,10 +67,7 @@ class date_trunc(FunctionElement):
 def pg_date_trunc(element, compiler, **kw):
     pg_map = {"H": "hour", "D": "day", "M": "month", "Y": "year"}
     period, date = list(element.clauses)
-    return "date_trunc('%s', %s)" % (
-        pg_map[period.value.value],
-        compiler.process(date, **kw),
-    )
+    return f"date_trunc('{pg_map[period.value.value]}', {compiler.process(date, **kw)})"
 
 
 @compiles(date_trunc, 'sqlite')
@@ -113,7 +110,6 @@ class Upsert(Insert):
 
 @compiles(Upsert, 'postgresql')
 def upsert_pg(element, compiler, **kw):
-
     index_elements = element.index_elements
     values = element.values
     column = element.column
@@ -146,8 +142,9 @@ def upsert_sql(element, compiler, **kw):
 
     stmt = insert(table).values(values)
     raw_sql = compiler.process(stmt)
-    upsert_stmt = "ON CONFLICT ({}) DO UPDATE SET {}={}+{}".format(
-        ",".join(index_elements), column.name, column.name, incr
+    upsert_stmt = (
+        f"ON CONFLICT ({','.join(index_elements)}) "
+        f"DO UPDATE SET {column.name}={column.name}+{incr}"
     )
 
     return raw_sql + " " + upsert_stmt
@@ -335,12 +332,21 @@ class Dao:
 
         return channel
 
-    def cleanup_channel_db(self, channel_name: str, dry_run: bool = False):
+    def cleanup_channel_db(
+        self,
+        channel_name: str,
+        package_name: Optional[str] = None,
+        dry_run: bool = False,
+    ):
         # remove all Packages without PackageVersions
         package_without_package_versions = []
         all_packages = self.db.query(Package).filter(
             Package.channel_name == channel_name
         )
+        if package_name:
+            all_packages = all_packages.filter(
+                PackageVersion.package_name == package_name
+            )
         for each_package in all_packages:
             all_package_versions = (
                 self.db.query(PackageVersion)
@@ -372,6 +378,10 @@ class Dao:
         all_packages = self.db.query(Package).filter(
             Package.channel_name == channel_name
         )
+        if package_name:
+            all_packages = all_packages.filter(
+                PackageVersion.package_name == package_name
+            )
         for each_package in all_packages:
             if each_package.channeldata is not None:
                 each_package_channeldata = json.loads(each_package.channeldata)
@@ -392,12 +402,19 @@ class Dao:
 
         if not dry_run:
             self.db.commit()
-        logger.info(f"Done cleaning up db for {channel_name}")
+        if not package_name:
+            logger.info(f"Done cleaning up db for {channel_name}")
+        else:
+            logger.info(f"Done cleaning up db for {channel_name}/{package_name}")
 
         # Re-sort all PackageVersions
         all_packages = self.db.query(Package).filter(
             Package.channel_name == channel_name
         )
+        if package_name:
+            all_packages = all_packages.filter(
+                PackageVersion.package_name == package_name
+            )
         for x, each_package in enumerate(all_packages):
             all_versions_for_each_package = (
                 self.db.query(PackageVersion)
@@ -425,12 +442,16 @@ class Dao:
 
         if not dry_run:
             self.db.commit()
-        logger.info(f"Done sorting package versions for {channel_name}")
+        if not package_name:
+            logger.info(f"Done sorting package versions for {channel_name}")
+        else:
+            logger.info(
+                f"Done sorting package versions for {channel_name}/{package_name}"
+            )
 
     def create_channel_mirror(
         self, channel_name: str, url: str, api_endpoint: str, metrics_endpoint: str
     ):
-
         channel_mirror = ChannelMirror(
             channel_name=channel_name,
             url=url,
@@ -450,7 +471,6 @@ class Dao:
         self.db.commit()
 
     def update_channel(self, channel_name, data: dict):
-
         self.db.query(Channel).filter(Channel.name == channel_name).update(
             data, synchronize_session=False
         )
@@ -470,7 +490,6 @@ class Dao:
         q: Optional[str] = None,
         order_by: Optional[str] = None,
     ):
-
         query = self.db.query(Package).filter(Package.channel_name == channel_name)
 
         if q:
@@ -674,7 +693,6 @@ class Dao:
         self.db.commit()
 
     def get_api_keys_with_members(self, user_id, api_key_id=None):
-
         user_role_api_keys = (
             self.db.query(ApiKey)
             .filter(ApiKey.owner_id == user_id)
@@ -781,7 +799,7 @@ class Dao:
         return db_api_key
 
     def get_api_key(self, key):
-        return self.db.query(ApiKey).get(key)
+        return self.db.get(ApiKey, key)
 
     def create_version(
         self,
@@ -822,7 +840,6 @@ class Dao:
         package_version = existing_versions.one_or_none()
 
         if not package_version:
-
             all_existing_versions = (
                 self.db.query(PackageVersion)
                 .filter(PackageVersion.channel_name == channel_name)
@@ -898,7 +915,12 @@ class Dao:
         return package_version
 
     def get_package_versions(
-        self, package, time_created_ge: datetime = None, version_match_str: str = None
+        self,
+        package,
+        time_created_ge: datetime = None,
+        version_match_str: str = None,
+        skip: int = 0,
+        limit: int = -1,
     ):
         ApiKeyProfile = aliased(Profile)
 
@@ -915,7 +937,6 @@ class Dao:
             query = query.filter(PackageVersion.time_created >= time_created_ge)
 
         if version_match_str:
-
             if version_match:
                 query = query.filter(
                     version_match(PackageVersion.version, version_match_str)
@@ -926,12 +947,14 @@ class Dao:
                     "database_plugin_path correctly for support!"
                 )
 
-        return query.all()
+        if limit < 0:
+            return query.all()
+        else:
+            return get_paginated_result(query, skip, limit)
 
     def get_package_version_by_filename(
         self, channel_name: str, package_name: str, filename: str, platform: str
     ):
-
         query = (
             self.db.query(PackageVersion)
             .filter(PackageVersion.channel_name == channel_name)
@@ -984,7 +1007,6 @@ class Dao:
         )
 
         if channel_size_limit is not None:
-
             allowed = (channel_size + size) <= channel_size_limit
 
             if not allowed:
@@ -993,7 +1015,6 @@ class Dao:
                 )
 
     def update_channel_size(self, channel_name: str):
-
         channel_size = (
             self.db.query(func.sum(PackageVersion.size).label('size'))
             .filter(PackageVersion.channel_name == channel_name)
@@ -1006,8 +1027,10 @@ class Dao:
         self.update_channel(channel_name, {"size": channel_size})
 
     def create_user_with_role(self, user_name: str, role: Optional[str] = None):
-        """create a user without a profile or return a user if already exists and replace
-        role"""
+        """
+        create a user without a profile or return a user if already exists
+        and replace role
+        """
         user = self.db.query(User).filter(User.username == user_name).one_or_none()
         if not user:
             user = User(id=uuid.uuid4().bytes, username=user_name, role=role)
@@ -1053,7 +1076,7 @@ class Dao:
                     if user_email:
                         raise IntegrityError(
                             f"User {username} already registered "
-                            "with email {user_email.email}",
+                            f"with email {user_email.email}",
                             "",
                             "",
                         )
@@ -1131,7 +1154,6 @@ class Dao:
         return get_paginated_result(tasks, skip, limit)
 
     def create_job(self, user_id, job_model):
-
         serialized = job_model.manifest.encode('ascii')
         job = Job(
             owner_id=user_id,
@@ -1152,7 +1174,6 @@ class Dao:
         timestamp: Optional[datetime] = None,
         incr: int = 1,
     ):
-
         metric_name = "download"
 
         self.db.query(PackageVersion).filter(
@@ -1168,7 +1189,6 @@ class Dao:
 
         all_values = []
         for interval in IntervalType:
-
             values = {
                 'channel_name': channel,
                 'platform': platform,
@@ -1211,7 +1231,6 @@ class Dao:
         end: Optional[datetime] = None,
         fill_zeros: bool = False,
     ):
-
         m = PackageVersionMetric
         v = PackageVersion
 
@@ -1278,7 +1297,6 @@ class Dao:
         start: Optional[datetime] = None,
         end: Optional[datetime] = None,
     ):
-
         m = PackageVersionMetric
 
         q = (
