@@ -2,6 +2,7 @@
 # Distributed under the terms of the Modified BSD License.
 import asyncio
 import datetime
+import hashlib
 import json
 import logging
 import os
@@ -12,7 +13,7 @@ from collections import Counter
 from concurrent.futures import ThreadPoolExecutor
 from contextlib import contextmanager
 from email.utils import formatdate
-from tempfile import SpooledTemporaryFile
+from tempfile import SpooledTemporaryFile, TemporaryFile
 from typing import List, Optional, Tuple, Type
 
 import pydantic
@@ -87,7 +88,12 @@ from quetz.rest_models import ChannelActionEnum, CPRole
 from quetz.tasks import indexing
 from quetz.tasks.common import Task
 from quetz.tasks.mirror import RemoteRepository, download_remote_file
-from quetz.utils import TicToc, generate_random_key, parse_query
+from quetz.utils import (
+    TicToc,
+    background_task_wrapper,
+    generate_random_key,
+    parse_query,
+)
 
 from .condainfo import CondaInfo
 
@@ -274,7 +280,6 @@ async def me(
 
 
 def get_users_handler(dao, q, auth, skip, limit):
-
     user_id = auth.assert_user()
 
     results = dao.get_users(skip, limit, q)
@@ -358,7 +363,6 @@ def get_user_packages(
     dao: Dao = Depends(get_dao),
     auth: authorization.Rules = Depends(get_rules),
 ):
-
     return list_user_packages(username, dao, auth, 0, -1)
 
 
@@ -450,7 +454,6 @@ def get_user_role(
     dao: Dao = Depends(get_dao),
     auth: authorization.Rules = Depends(get_rules),
 ):
-
     user = dao.get_user_by_username(username)
 
     if not user:
@@ -470,7 +473,6 @@ def set_user_role(
     dao: Dao = Depends(get_dao),
     auth: authorization.Rules = Depends(get_rules),
 ):
-
     user = dao.get_user_by_username(username)
 
     if not user:
@@ -539,7 +541,6 @@ def post_channel_mirror(
     dao: Dao = Depends(get_dao),
     remote_session: requests.Session = Depends(get_remote_session),
 ):
-
     auth.assert_register_mirror(channel_name)
 
     logger.debug(f"registering mirror {mirror.url}")
@@ -597,7 +598,6 @@ def get_channel_mirrors(
 
 @api_router.delete(
     "/channels/{channel_name}/mirrors/{mirror_id}",
-    response_model=List[rest_models.ChannelMirror],
     tags=["channels"],
 )
 def delete_channel_mirror(
@@ -620,7 +620,6 @@ def delete_channel(
     dao: Dao = Depends(get_dao),
     auth: authorization.Rules = Depends(get_rules),
 ):
-
     auth.assert_delete_channel(channel)
     dao.delete_channel(channel.name)
     try:
@@ -640,7 +639,6 @@ def put_mirror_channel_actions(
     dao: Dao = Depends(get_dao),
     task: Task = Depends(get_tasks_worker),
 ):
-
     new_job = task.execute_channel_action(
         action.action,
         channel,
@@ -663,7 +661,6 @@ def post_channel(
     config=Depends(get_config),
     session: requests.Session = Depends(get_remote_session),
 ):
-
     user_id = auth.assert_user()
 
     existing_channel = dao.get_channel(new_channel.name)
@@ -717,7 +714,8 @@ def post_channel(
 
     channel = dao.create_channel(new_channel, user_id, authorization.OWNER, size_limit)
     pkgstore.create_channel(new_channel.name)
-    indexing.update_indexes(dao, pkgstore, new_channel.name)
+    if not is_proxy:
+        indexing.update_indexes(dao, pkgstore, new_channel.name)
 
     # register mirror
     if is_mirror and register_mirror:
@@ -758,7 +756,6 @@ def patch_channel(
     channel: db_models.Channel = Depends(get_channel_or_fail),
     db=Depends(get_db),
 ):
-
     auth.assert_update_channel_info(channel.name)
 
     user_attrs = channel_data.dict(exclude_unset=True)
@@ -837,22 +834,27 @@ def get_package(package: db_models.Package = Depends(get_package_or_fail)):
 
 @api_router.delete(
     "/channels/{channel_name}/packages/{package_name}",
-    response_model=rest_models.Package,
     tags=["packages"],
 )
 def delete_package(
+    background_tasks: BackgroundTasks,
     package: db_models.Package = Depends(get_package_or_fail),
     db=Depends(get_db),
     auth: authorization.Rules = Depends(get_rules),
     dao: Dao = Depends(get_dao),
 ):
-
     auth.assert_package_delete(package)
 
     filenames = [
         os.path.join(version.platform, version.filename)
         for version in package.package_versions  # type: ignore
     ]
+
+    # get current platform containing the package
+    platforms = set(
+        [version.platform for version in package.package_versions]  # type: ignore
+    )
+
     channel_name = package.channel_name
 
     db.delete(package)
@@ -863,6 +865,10 @@ def delete_package(
 
     dao.update_channel_size(channel_name)
 
+    wrapped_bg_task = background_task_wrapper(indexing.update_indexes, logger)
+    # Background task to update indexes
+    background_tasks.add_task(wrapped_bg_task, dao, pkgstore, channel_name, platforms)
+
 
 @api_router.post(
     "/channels/{channel_name}/packages", status_code=201, tags=["packages"]
@@ -875,7 +881,6 @@ def post_package(
     auth: authorization.Rules = Depends(get_rules),
     dao: Dao = Depends(get_dao),
 ):
-
     user_id = auth.assert_user()
     auth.assert_create_package(channel.name)
     pm.hook.validate_new_package(
@@ -904,7 +909,6 @@ def get_channel_members(
     dao: Dao = Depends(get_dao),
     auth: authorization.Rules = Depends(get_rules),
 ):
-
     auth.assert_list_channel_members(channel.name)
     member_list = dao.get_channel_members(channel.name)
 
@@ -919,7 +923,6 @@ def post_channel_member(
     db=Depends(get_db),
     auth: authorization.Rules = Depends(get_rules),
 ):
-
     if not dao.get_user_by_username(new_member.username):
         raise HTTPException(
             status_code=status.HTTP_404_NOT_FOUND,
@@ -946,7 +949,6 @@ def delete_channel_member(
     db=Depends(get_db),
     auth: authorization.Rules = Depends(get_rules),
 ):
-
     if not dao.get_user_by_username(username):
         raise HTTPException(
             status_code=status.HTTP_404_NOT_FOUND,
@@ -977,7 +979,6 @@ def get_package_members(
     package: db_models.Package = Depends(get_package_or_fail),
     dao: Dao = Depends(get_dao),
 ):
-
     member_list = dao.get_package_members(package.channel.name, package.name)
 
     return member_list
@@ -994,7 +995,6 @@ def post_package_member(
     dao: Dao = Depends(get_dao),
     auth: authorization.Rules = Depends(get_rules),
 ):
-
     auth.assert_add_package_member(package.channel.name, package.name, new_member.role)
 
     channel_member = dao.get_package_member(
@@ -1005,7 +1005,7 @@ def post_package_member(
             status_code=status.HTTP_409_CONFLICT,
             detail=(
                 f"Member {new_member.username} in "
-                "{package.channel.name}/{package.name} exists"
+                f"{package.channel.name}/{package.name} exists"
             ),
         )
 
@@ -1023,7 +1023,6 @@ def get_package_versions(
     time_created__ge: datetime.datetime = None,
     version_match_str: str = None,
 ):
-
     version_profile_list = dao.get_package_versions(
         package, time_created__ge, version_match_str
     )
@@ -1036,6 +1035,34 @@ def get_package_versions(
     return version_list
 
 
+@api_router.get(
+    "/paginated/channels/{channel_name}/packages/{package_name}/versions",
+    response_model=rest_models.PaginatedResponse[rest_models.PackageVersion],
+    tags=["packages"],
+)
+def get_paginated_package_versions(
+    package: db_models.Package = Depends(get_package_or_fail),
+    dao: Dao = Depends(get_dao),
+    skip: int = 0,
+    limit: int = PAGINATION_LIMIT,
+    time_created__ge: datetime.datetime = None,
+    version_match_str: str = None,
+):
+    version_profile_list = dao.get_package_versions(
+        package, time_created__ge, version_match_str, skip, limit
+    )
+    version_list = []
+
+    for version, profile, api_key_profile in version_profile_list['result']:
+        version_data = rest_models.PackageVersion.from_orm(version)
+        version_list.append(version_data)
+
+    return {
+        'pagination': version_profile_list['pagination'],
+        'result': version_list,
+    }
+
+
 @api_router.get(
     "/channels/{channel_name}/packages/{package_name}/versions/{platform}/{filename}",
     response_model=rest_models.PackageVersion,
@@ -1064,7 +1091,6 @@ def get_package_version(
 
 @api_router.delete(
     "/channels/{channel_name}/packages/{package_name}/versions/{platform}/{filename}",
-    response_model=rest_models.PackageVersion,
     tags=["packages"],
 )
 def delete_package_version(
@@ -1072,11 +1098,11 @@ def delete_package_version(
     filename: str,
     channel_name: str,
     package_name: str,
+    background_tasks: BackgroundTasks,
     dao: Dao = Depends(get_dao),
     db=Depends(get_db),
     auth: authorization.Rules = Depends(get_rules),
 ):
-
     version = dao.get_package_version_by_filename(
         channel_name, package_name, filename, platform
     )
@@ -1095,8 +1121,13 @@ def delete_package_version(
     path = os.path.join(platform, filename)
     pkgstore.delete_file(channel_name, path)
 
+    dao.cleanup_channel_db(channel_name, package_name)
     dao.update_channel_size(channel_name)
 
+    wrapped_bg_task = background_task_wrapper(indexing.update_indexes, logger)
+    # Background task to update indexes
+    background_tasks.add_task(wrapped_bg_task, dao, pkgstore, channel_name, [platform])
+
 
 @api_router.get(
     "/packages/search/", response_model=List[rest_models.PackageSearch], tags=["search"]
@@ -1190,7 +1221,6 @@ def post_api_key(
     dao: Dao = Depends(get_dao),
     auth: authorization.Rules = Depends(get_rules),
 ):
-
     auth.assert_create_api_key_roles(api_key.roles)
 
     user_id = auth.assert_user()
@@ -1282,6 +1312,90 @@ def post_file_to_package(
     handle_package_files(package.channel, files, dao, auth, force, package=package)
     dao.update_channel_size(package.channel_name)
 
+    wrapped_bg_task = background_task_wrapper(indexing.update_indexes, logger)
+    # Background task to update indexes
+    background_tasks.add_task(wrapped_bg_task, dao, pkgstore, package.channel_name)
+
+
+@api_router.post(
+    "/channels/{channel_name}/upload/{filename}", status_code=201, tags=["upload"]
+)
+async def post_upload(
+    background_tasks: BackgroundTasks,
+    request: Request,
+    channel_name: str,
+    filename: str,
+    sha256: str,
+    force: bool = False,
+    dao: Dao = Depends(get_dao),
+    auth: authorization.Rules = Depends(get_rules),
+):
+    logger.debug(
+        f"Uploading file {filename} with checksum {sha256} to channel {channel_name}"
+    )
+
+    upload_hash = hashlib.sha256()
+
+    body = TemporaryFile()
+    async for chunk in request.stream():
+        body.write(chunk)
+        upload_hash.update(chunk)
+
+    if sha256 and upload_hash.hexdigest() != sha256:
+        raise HTTPException(
+            status_code=status.HTTP_406_NOT_ACCEPTABLE, detail="Wrong SHA256 checksum"
+        )
+
+    user_id = auth.assert_user()
+    auth.assert_create_package(channel_name)
+    condainfo = CondaInfo((body), filename)
+    dest = os.path.join(condainfo.info["subdir"], filename)
+
+    body.seek(0)
+    pkgstore.add_package(body, channel_name, dest)
+
+    package_name = str(condainfo.info.get("name"))
+    package_data = rest_models.Package(
+        name=package_name,
+        summary=str(condainfo.about.get("summary", "n/a")),
+        description=str(condainfo.about.get("description", "n/a")),
+    )
+    if not dao.get_package(channel_name, package_name):
+        dao.create_package(
+            channel_name,
+            package_data,
+            user_id,
+            authorization.OWNER,
+        )
+
+    # Update channeldata info
+    dao.update_package_channeldata(channel_name, package_name, condainfo.channeldata)
+
+    try:
+        version = dao.create_version(
+            channel_name=channel_name,
+            package_name=package_name,
+            package_format=condainfo.package_format,
+            platform=condainfo.info["subdir"],
+            version=condainfo.info["version"],
+            build_number=condainfo.info["build_number"],
+            build_string=condainfo.info["build"],
+            size=condainfo.info["size"],
+            filename=filename,
+            info=json.dumps(condainfo.info),
+            uploader_id=user_id,
+            upsert=force,
+        )
+    except IntegrityError:
+        logger.debug(f"duplicate package '{package_name}' in channel '{channel_name}'")
+        raise HTTPException(status_code=status.HTTP_409_CONFLICT, detail="Duplicate")
+
+    pm.hook.post_add_package_version(version=version, condainfo=condainfo)
+
+    wrapped_bg_task = background_task_wrapper(indexing.update_indexes, logger)
+    # Background task to update indexes
+    background_tasks.add_task(wrapped_bg_task, dao, pkgstore, channel_name)
+
 
 @api_router.post("/channels/{channel_name}/files/", status_code=201, tags=["files"])
 def post_file_to_channel(
@@ -1298,8 +1412,9 @@ def post_file_to_channel(
 
     dao.update_channel_size(channel.name)
 
+    wrapped_bg_task = background_task_wrapper(indexing.update_indexes, logger)
     # Background task to update indexes
-    background_tasks.add_task(indexing.update_indexes, dao, pkgstore, channel.name)
+    background_tasks.add_task(wrapped_bg_task, dao, pkgstore, channel.name)
 
 
 @retry(
@@ -1416,6 +1531,11 @@ def handle_package_files(
 
     for file, condainfo in zip(files, conda_infos):
         logger.debug(f"Handling {condainfo.info['name']} -> {file.filename}")
+
+        def _delete_file(condainfo, filename):
+            dest = os.path.join(condainfo.info["subdir"], file.filename)
+            pkgstore.delete_file(channel.name, dest)
+
         package_type = "tar.bz2" if file.filename.endswith(".tar.bz2") else "conda"
         UPLOAD_COUNT.labels(
             channel=channel.name,
@@ -1431,25 +1551,22 @@ def handle_package_files(
         # check that the filename matches the package name
         # TODO also validate version and build string
         if parts[0] != condainfo.info["name"]:
+            _delete_file(condainfo, file.filename)
             raise HTTPException(
                 status_code=status.HTTP_400_BAD_REQUEST,
                 detail="filename does not match package name",
             )
         if package and (parts[0] != package.name or package_name != package.name):
+            _delete_file(condainfo, file.filename)
             raise HTTPException(
                 status_code=status.HTTP_400_BAD_REQUEST,
                 detail=(
-                    f"requested package endpoint '{package.name}'"
+                    f"requested package endpoint '{package.name}' "
                     f"does not match the uploaded package name '{parts[0]}'"
                 ),
             )
 
-        def _delete_file(condainfo, filename):
-            dest = os.path.join(condainfo.info["subdir"], file.filename)
-            pkgstore.delete_file(channel.name, dest)
-
         if not package and not dao.get_package(channel.name, package_name):
-
             try:
                 if not channel_proxylist or package_name not in channel_proxylist:
                     pm.hook.validate_new_package(
@@ -1543,7 +1660,6 @@ def invalid_api():
 
 @app.on_event("startup")
 def start_sync_download_counts():
-
     global download_counts
     wait_time = 1  # seconds
 
@@ -1608,7 +1724,6 @@ def serve_path(
     session=Depends(get_remote_session),
     dao: Dao = Depends(get_dao),
 ):
-
     chunk_size = 10_000
 
     is_package_request = path.endswith((".tar.bz2", ".conda"))
