@@ -31,20 +31,9 @@ def sqlite_in_memory():
     return False
 
 
-@pytest.fixture
-def package_name():
-    return "my-package"
-
-
-@pytest.fixture
-def channel_name():
-    return "my-channel"
-
-
 def add_package_version(
     filename, package_version, channel_name, user, dao, package_name=None
 ):
-
     if not package_name:
         package_name = "test-package"
 
@@ -78,7 +67,6 @@ def package_version(
     dao: Dao,
     config: Config,
 ):
-
     pkgstore = config.get_package_store()
 
     filename = "test-package-0.1-0.tar.bz2"
@@ -98,19 +86,8 @@ def package_version(
     db.commit()
 
 
-@pytest.fixture
-def channel_role():
-    return "owner"
-
-
-@pytest.fixture
-def package_role():
-    return "owner"
-
-
 @pytest.fixture
 def public_channel(dao: Dao, user, channel_role, channel_name, db):
-
     channel_data = Channel(name=channel_name, private=False)
     channel = dao.create_channel(channel_data, user.id, channel_role)
 
@@ -122,7 +99,6 @@ def public_channel(dao: Dao, user, channel_role, channel_name, db):
 
 @pytest.fixture
 def public_package(db, user, public_channel, dao, package_role, package_name):
-
     package_data = Package(name=package_name)
 
     package = dao.create_package(
@@ -134,7 +110,6 @@ def public_package(db, user, public_channel, dao, package_role, package_name):
 
 @pytest.fixture
 def manager(config, db):
-
     manager = SubprocessWorker(config)
     yield manager
     manager._executor.shutdown()
@@ -176,7 +151,6 @@ def dummy_func(package_version: dict):
 
 @pytest.mark.asyncio
 async def test_create_job(db, user, package_version, supervisor):
-
     func_serialized = pickle.dumps(func)
     job = Job(owner_id=user.id, manifest=func_serialized, items_spec="*")
     db.add(job)
@@ -207,7 +181,6 @@ async def test_create_job(db, user, package_version, supervisor):
 async def test_run_tasks_only_on_new_versions(
     db, user, package_version, dao, channel_name, package_name, supervisor
 ):
-
     func_serialized = pickle.dumps(dummy_func)
     job = Job(owner_id=user.id, manifest=func_serialized, items_spec="*")
     db.add(job)
@@ -257,7 +230,6 @@ async def test_run_tasks_only_on_new_versions(
 
 @pytest.mark.asyncio
 async def test_running_task(db, user, package_version, supervisor):
-
     func_serialized = pickle.dumps(long_running)
     job = Job(owner_id=user.id, manifest=func_serialized, items_spec="*")
     db.add(job)
@@ -338,7 +310,6 @@ async def test_restart_worker_process(
 
 @pytest.mark.asyncio
 async def test_failed_task(db, user, package_version, supervisor):
-
     func_serialized = pickle.dumps(failed_func)
     job = Job(owner_id=user.id, manifest=func_serialized, items_spec="*")
     db.add(job)
@@ -360,7 +331,6 @@ async def test_failed_task(db, user, package_version, supervisor):
 
 @pytest.mark.parametrize("items_spec", [""])
 def test_empty_package_spec(db, user, package_version, caplog, items_spec, supervisor):
-
     func_serialized = pickle.dumps(func)
     job = Job(owner_id=user.id, manifest=func_serialized, items_spec=items_spec)
     db.add(job)
@@ -517,7 +487,6 @@ def test_parse_conda_spec():
     ],
 )
 def test_filter_versions(db, user, package_version, spec, n_tasks, supervisor):
-
     func_serialized = pickle.dumps(func)
     job = Job(
         owner_id=user.id,
@@ -536,7 +505,6 @@ def test_filter_versions(db, user, package_version, spec, n_tasks, supervisor):
 
 @pytest.mark.parametrize("user_role", ["owner"])
 def test_refresh_job(auth_client, user, db, package_version, supervisor):
-
     func_serialized = pickle.dumps(dummy_func)
     job = Job(
         owner_id=user.id,
@@ -663,7 +631,7 @@ def test_post_new_job_from_plugin(
     )
     assert response.status_code == 201
     job_id = response.json()['id']
-    job = db.query(Job).get(job_id)
+    job = db.get(Job, job_id)
     assert job.manifest.decode('ascii') == manifest
 
     sync_supervisor.run_once()
@@ -681,13 +649,12 @@ def test_post_new_job_from_plugin(
 def test_post_new_job_with_handler(
     auth_client, user, db, mock_action, sync_supervisor, package_version
 ):
-
     response = auth_client.post(
         "/api/jobs", json={"items_spec": "*", "manifest": "test_action"}
     )
     assert response.status_code == 201
     job_id = response.json()['id']
-    job = db.query(Job).get(job_id)
+    job = db.get(Job, job_id)
     assert job.status == JobStatus.pending
     assert job.manifest.decode('ascii') == "test_action"
 
@@ -730,7 +697,7 @@ def test_filter_jobs_by_status(auth_client, db, user, status, job_ids):
 
     db.commit()
 
-    query = "&".join(["status={}".format(s) for s in status])
+    query = "&".join([f"status={s}" for s in status])
 
     response = auth_client.get(f"/api/jobs?{query}")
 
@@ -763,7 +730,6 @@ def test_validate_query_string(auth_client, query_str, ok):
 
 @pytest.fixture
 def many_jobs(db, user):
-
     n_jobs = 5
     jobs = []
     for i in range(n_jobs):
@@ -787,7 +753,6 @@ def many_jobs(db, user):
 @pytest.mark.parametrize("user_role", ["owner"])
 @pytest.mark.parametrize("skip,limit", [(0, 2), (1, -1), (2, 1), (2, 5)])
 def test_jobs_pagination(auth_client, skip, limit, many_jobs):
-
     n_jobs = len(many_jobs)
 
     response = auth_client.get(f"/api/jobs?skip={skip}&limit={limit}")
@@ -838,7 +803,6 @@ def test_get_tasks(
 
 @pytest.fixture()
 def other_user(db):
-
     other_user = User(id=uuid.uuid4().bytes, username='otheruser')
 
     db.add(other_user)
@@ -945,7 +909,6 @@ def test_update_periodic_action(sync_supervisor, db, action_job, mock_action):
 
 @pytest.mark.parametrize("start_date", [datetime(1960, 1, 1, 10, 0, 0), None])
 def test_run_action_once(sync_supervisor, db, action_job, mock_action, start_date):
-
     # job should start immediatedly
     action_job.start_at = start_date
     db.commit()
@@ -967,7 +930,6 @@ def test_run_action_once(sync_supervisor, db, action_job, mock_action, start_dat
 
 
 def test_run_action_after_delay(sync_supervisor, db, action_job, mock_action, mocker):
-
     action_job.start_at = datetime(3020, 1, 1, 10, 0)
     db.commit()
 
@@ -994,7 +956,6 @@ def test_run_action_after_delay(sync_supervisor, db, action_job, mock_action, mo
 def test_run_periodic_action(
     sync_supervisor, db, action_job, mock_action, mocker, start_date
 ):
-
     action_job.repeat_every_seconds = 10
     action_job.start_date = start_date
     now = datetime.utcnow()
